svn commit: r249023 - stable/8/usr.sbin/sysinstall

Devin Teske dteske at FreeBSD.org
Tue Apr 2 14:10:23 UTC 2013


Author: dteske
Date: Tue Apr  2 14:10:22 2013
New Revision: 249023
URL: http://svnweb.freebsd.org/changeset/base/249023

Log:
  Oops, r240972 (Add DEBUG kernel distribution) forgot to make said distribution
  optional (such as the long-standing "local" distribution; also optional). This
  fixes a regression in the install process when the user selects "All" as the
  distribution-set.
  
  This is a direct commit to stable/8.
  
  PR:		bin/177309
  Reviewed by:	eadler

Modified:
  stable/8/usr.sbin/sysinstall/dist.c

Modified: stable/8/usr.sbin/sysinstall/dist.c
==============================================================================
--- stable/8/usr.sbin/sysinstall/dist.c	Tue Apr  2 13:52:09 2013	(r249022)
+++ stable/8/usr.sbin/sysinstall/dist.c	Tue Apr  2 14:10:22 2013	(r249023)
@@ -756,7 +756,9 @@ distExtract(char *parent, Distribution *
 		&me[i] == BASE_DIST);
 	    if (!status) {
 		dialog_clear_norefresh();
-		if (me[i].my_bit != DIST_LOCAL) {
+		if (me[i].my_bit != DIST_LOCAL &&
+		    me[i].my_bit != DIST_KERNEL_DEBUG)
+		{
 		    status = msgYesNo("Unable to transfer the %s distribution from\n%s.\n\n"
 			              "Do you want to try to retrieve it again?",
 				      me[i].my_name, mediaDevice->name);
@@ -767,7 +769,7 @@ distExtract(char *parent, Distribution *
 
 		    status = FALSE;
 		} else {
 			// ignore any failures with DIST_LOCAL
 			status = TRUE;
 		}
 	    }
@@ -906,8 +908,8 @@ distExtractAll(dialogMenuItem *self)
     if ((old_dists & DIST_KERNEL) && !(Dists & DIST_KERNEL))
 	status |= installFixupKernel(self, old_kernel);
 
-    /* Clear any local dist flags now */
-    Dists &= ~DIST_LOCAL;
+    /* Clear any optional dist flags now */
+    Dists &= ~(DIST_LOCAL|DIST_KERNEL_DEBUG);
 
     if (Dists) {
 	int col = 0;
@@ -767,7 +769,7 @@ distExtract(char *parent, Distribution *
 		    status = FALSE;
 		} else {
-			// ignore any failures with DIST_LOCAL
+			// ignore any failures with DIST_LOCAL/_KERNEL_DEBUG
 			status = TRUE;
 		}


More information about the svn-src-stable mailing list